==> webservices-osgi-2.4.0-sources.jar: com/sun/xml/ws/security/trust/elements/CancelTarget.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2010-2017 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://oss.oracle.com/licenses/CDDL+GPL-1.1
 * or LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

/*
 * $Id: CancelTarget.java,v 1.2 2010-10-21 15:35:40 snajper Exp $
 */

package com.sun.xml.ws.security.trust.elements;

import com.sun.xml.ws.security.trust.elements.str.SecurityTokenReference;
import com.sun.xml.ws.security.Token;

/**
 * Defines Binding for requesting security tokens to be cancelled.
 *
 * @author WS-Trust Implementation Team
 */
public interface CancelTarget {
    
    /**
     *Constants denoting type of Cancel Target
     */
    public static final String STR_TARGET_TYPE="SecurityTokenReference";
    public static final String CUSTOM_TARGET_TYPE = "Custom";
    
    /**
     * Get the type of the Cancel Target information item
     */
    String getTargetType();
    
    /**
     * Gets the value of the any property.
     * 
     * @return
     *     possible object is
     *     {@link Object }
     *     
     */
    Object getAny();

    /**
     * Sets the value of the any property.
     * 
     * @param value
     *     allowed object is
     *     {@link Object }
     *     
     */
    void setAny(Object value);
    
     /**
     * Set the STR for the Token to be Cancelled
     */
    void setSecurityTokenReference(SecurityTokenReference ref);
    
    /**
     * Get the STR for the Token to be Cancelled
     */
    SecurityTokenReference getSecurityTokenReference();
    
    /**
     * Set the token to be Cancelled
     */
    void setToken(Token token);
    
     /**
     * Get the token to be Cancelled
     */
    Token getToken();
    
}

==> webservices-osgi-4.0.0-sources.jar: com/sun/xml/ws/security/trust/elements/CancelTarget.java <==
/*
 * Copyright (c) 2010, 2022 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Distribution License v. 1.0, which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

/*
 * $Id: CancelTarget.java,v 1.2 2010-10-21 15:35:40 snajper Exp $
 */

package com.sun.xml.ws.security.trust.elements;

import com.sun.xml.ws.security.trust.elements.str.SecurityTokenReference;
import com.sun.xml.ws.security.Token;

/**
 * Defines Binding for requesting security tokens to be cancelled.
 *
 * @author WS-Trust Implementation Team
 */
public interface CancelTarget {

    /**
     *Constants denoting type of Cancel Target
     */
    String STR_TARGET_TYPE="SecurityTokenReference";
    String CUSTOM_TARGET_TYPE = "Custom";

    /**
     * Get the type of the Cancel Target information item
     */
    String getTargetType();

    /**
     * Gets the value of the any property.
     *
     * @return
     *     possible object is
     *     {@link Object }
     *
     */
    Object getAny();

    /**
     * Sets the value of the any property.
     *
     * @param value
     *     allowed object is
     *     {@link Object }
     *
     */
    void setAny(Object value);

     /**
     * Set the STR for the Token to be Cancelled
     */
    void setSecurityTokenReference(SecurityTokenReference ref);

    /**
     * Get the STR for the Token to be Cancelled
     */
    SecurityTokenReference getSecurityTokenReference();

    /**
     * Set the token to be Cancelled
     */
    void setToken(Token token);

     /**
     * Get the token to be Cancelled
     */
    Token getToken();

}
